==> mobile_pos-0.8.12.tar.gz: lib/src/views/card_payment/card_balance.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/shared_widgets/powerby_by_raven_widget.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';

class CardBalance extends StatefulWidget {
  final double balance;
  final String maskedPan;
  const CardBalance(
      {super.key, required this.balance, required this.maskedPan});

  @override
  State<CardBalance> createState() => _CardBalanceState();
}

class _CardBalanceState extends State<CardBalance> {
  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        body: Padding(
      padding: const EdgeInsets.symmetric(horizontal: 20),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          const Gap(24),
          const RavenPayCloseButton(
            isArrow: true,
            text: "",
          ),
          const Gap(24),
          Align(
              alignment: Alignment.centerLeft,
              child: Text("Account Balance", style: headling1)),
          const Gap(8),
          Text("Below is your account details and your account balance.",
              style: subtitle.copyWith(fontWeight: FontWeight.w500)),
          const Gap(24),
          CardBalanceWidget(
            maskedPan: widget.maskedPan,
            balance: widget.balance.toString(),
          ),
          const Spacer(),
          RavenPayButton(
            buttonText: "Back To Dashboard",
            onPressed: () {
              Navigator.pop(context);
            },
          ),
          const Gap(16),
          PoweredByRaven(
            paddingBottom: Platform.isAndroid ? 16 : 0,
            fontSize: 9,
          ),
        ],
      ),
    ));
  }
}

class CardBalanceWidget extends StatelessWidget {
  final String balance;
  final String maskedPan;
  const CardBalanceWidget(
      {super.key, required this.balance, required this.maskedPan});

  @override
  Widget build(BuildContext context) {
    return Container(
        width: double.infinity,
        padding: const EdgeInsets.symmetric(horizontal: 20, vertical: 24),
        decoration: BoxDecoration(boxShadow: [
          BoxShadow(
              color: AppColors.ravenGrey4, spreadRadius: 0.2, blurRadius: 12)
        ], color: Colors.white, borderRadius: BorderRadius.circular(16)),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Container(
                height: 38,
                padding: const EdgeInsets.all(5),
                width: 39,
                decoration: BoxDecoration(
                    border:
                        Border.all(color: AppColors.ravenLightGrey, width: 4),
                    shape: BoxShape.circle,
                    color: AppColors.ravenLightGrey.withOpacity(0.4)),
                child: Image.asset(
                  loadAsset("bank_icon.png"),
                  color: pluginConfig.theme?.primaryColor,
                )),
            const Gap(12),
            Text("Account Balance",
                style: subtitle.copyWith(
                    fontWeight: FontWeight.w500, fontSize: 16)),
            const Gap(8),
            RavenPayMoneyWidget(
              amount: balance,
              fontSize: 28,
            ),
            const Divider(
              height: 24,
            ),
            const Gap(12),
            // item(name: "Card Type", value: "Verve"),
            // const Gap(18),
            item(name: "Card Number", value: maskedPan)
          ],
        ));
  }

  Row item({required String name, required String value}) {
    return Row(
      children: [
        Text(name,
            style:
                subtitle.copyWith(fontWeight: FontWeight.w500, fontSize: 14)),
        const Spacer(),
        Text(value,
            style: subtitle.copyWith(
                color: pluginConfig.theme?.primaryColor, fontSize: 14))
      ],
    );
  }
}

==> mobile_pos-1.1.1.tar.gz: lib/src/views/card_payment/card_balance.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/shared_widgets/powerby_by_raven_widget.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';

class CardBalance extends StatefulWidget {
  final double balance;
  final String maskedPan;
  const CardBalance(
      {super.key, required this.balance, required this.maskedPan});

  @override
  State<CardBalance> createState() => _CardBalanceState();
}

class _CardBalanceState extends State<CardBalance> {
  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        body: Padding(
      padding: const EdgeInsets.symmetric(horizontal: 20),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          const Gap(24),
          const RavenPayCloseButton(
            isArrow: true,
            text: "",
          ),
          const Gap(24),
          Align(
              alignment: Alignment.centerLeft,
              child: Text("Account Balance", style: headling1)),
          const Gap(8),
          Text("Below is your account details and your account balance.",
              style: subtitle.copyWith(fontWeight: FontWeight.w500)),
          const Gap(24),
          CardBalanceWidget(
            maskedPan: widget.maskedPan,
            balance: widget.balance.toString(),
          ),
          const Spacer(),
          RavenPayButton(
            buttonText: "Back To Dashboard",
            onPressed: () {
              Navigator.pop(context);
            },
          ),
          const Gap(24),
          PoweredByRaven(
            paddingBottom: Platform.isAndroid ? 16 : 0,
            fontSize: 9,
          ),
        ],
      ),
    ));
  }
}

class CardBalanceWidget extends StatelessWidget {
  final String balance;
  final String maskedPan;
  const CardBalanceWidget(
      {super.key, required this.balance, required this.maskedPan});

  @override
  Widget build(BuildContext context) {
    return Container(
        width: double.infinity,
        padding: const EdgeInsets.symmetric(horizontal: 20, vertical: 24),
        decoration: BoxDecoration(
            boxShadow: pluginTheme.isLightTheme
                ? [
                    BoxShadow(
                        color: AppColors.ravenGrey4,
                        spreadRadius: 0.2,
                        blurRadius: 12)
                  ]
                : null,
            color: pluginTheme.isLightTheme
                ? Colors.white
                : pluginTheme.getFGColor,
            borderRadius: BorderRadius.circular(16)),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Container(
                height: 38,
                padding: const EdgeInsets.all(5),
                width: 39,
                decoration: BoxDecoration(
                    border: Border.all(
                        color: pluginTheme.isLightTheme
                            ? AppColors.ravenLightGrey
                            : AppColors.ravenDark,
                        width: 4),
                    shape: BoxShape.circle,
                    color: AppColors.ravenLightGrey.withOpacity(0.4)),
                child: Image.asset(
                  loadAsset("bank_icon.png"),
                  color: pluginConfig.theme?.primaryColor,
                )),
            const Gap(12),
            Text("Account Balance",
                style: subtitle.copyWith(
                    fontWeight: FontWeight.w500, fontSize: 16)),
            const Gap(8),
            RavenPayMoneyWidget(
              amount: balance,
              fontSize: 28,
            ),
            const Divider(
              height: 24,
            ),
            const Gap(12),
            // item(name: "Card Type", value: "Verve"),
            // const Gap(18),
            item(name: "Card Number", value: maskedPan)
          ],
        ));
  }

  Row item({required String name, required String value}) {
    return Row(
      children: [
        Text(name,
            style:
                subtitle.copyWith(fontWeight: FontWeight.w500, fontSize: 14)),
        const Spacer(),
        Text(value,
            style: subtitle.copyWith(
                color: pluginConfig.theme?.primaryColor, fontSize: 14))
      ],
    );
  }
}
